/* Fmo.cc
 
  Fmo adj=1 vel=1.5 ff=0 <infile.H >outfile.H

  Applies anisotropic NMO operator (derived form a general MO ) to dataset, 
  given velocity vel, ff is the anelliptic moveout factor in Francis' approx.

  */
 
#include <SEPinit.h>
#include <fopfmo.h>
#include <Processnew.h>

main(int argc,char **argv) {
    
	// Seplib initialization
    SepInput * sepInput = SEPinit(argc,argv,SOURCE);

	// Check that we are getting floating point data
    if( sepInput->Info()->Esize() !=4 )
      seperr("esize !=4, expecting floating point data \n");

	// command line arguments
    int adj=0; sepInput->Getch("adj",adj);
    int inv=0;     sepInput->Getch("inv",inv);

    int niter=1;   sepInput->Getch("niter",niter);

    float vel=1.5; sepInput->Getch("vel",vel);
    float ff=0.;   sepInput->Getch("ff",ff);

	// make NMO
    fopFMO op((sepInput->Axis(1)),(sepInput->Axis(2)),1./vel,ff);

         // make input space from the seplib input
    floatspace input(sepInput);

        // Process data and output
    floatspacearray output = Processnew(input,op,adj, inv, niter );

        // write to output
    SepOutput *sepout = new SepOutput("stdout", output(0,0).sepData() );

    delete sepout;

    UnRef(sepInput);

    return 0;
}
