/* Kmo.cc
 
  Kmo adj=1 vel=1.5 m=0 <infile.H >outfile.H

  Applies Kirchhoff moveout operator (derived form a general MO ) to dataset, 
  given velocity vel.

  */
 
#include <SEPinit.h>

#include "./fopkmo.h"

#include <Processnew.h>

main(int argc,char **argv) {
    
	// Seplib initialization
    SepInput * sepInput = SEPinit(argc,argv,SOURCE);

	// Check that we are getting floating point data
    if( sepInput->Info()->Esize() !=4 )
      seperr("esize !=4, expecting floating point data \n");

	// command line arguments
    int adj=0;     sepInput->Getch("adj",adj);

    int inv=0;     sepInput->Getch("inv",inv);

    int niter=1;   sepInput->Getch("niter",niter);

    float vel=3.0; sepInput->Getch("vel",vel);

    float m=0;     sepInput->Getch("m",m);

    // just move it out, do not stack
    fopKMO op((sepInput->Axis(1)),(sepInput->Axis(2)),1./(vel/2),m);

         // make input space from the seplib input
    floatspace input(sepInput);

        // Process data and output
    floatspacearray output = Processnew(input,op,adj, inv, niter );

        // write to output
    SepOutput *sepout = new SepOutput("stdout", output(0,0).sepData() );

    delete sepout;

    UnRef(sepInput);

    return 0;
}
